@@ -1,70 +1,58 @@
 /*
-    SPDX-FileCopyrightText: 2011 Grégory Oestreicher <greg@kamago.net>
+    Copyright (c) 2011 Grégory Oestreicher <greg@kamago.net>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "davprincipalsearchjob.h"
-#include "davjobbase_p.h"
 
+#include "davmanager.h"
+#include "utils.h"
 #include "daverror.h"
-#include "davmanager_p.h"
-#include "utils_p.h"
 
-#include <KIO/DavJob>
 #include <KIO/Job>
+#include <KIO/DavJob>
 
-#include <QUrl>
+#include <QtCore/QUrl>
 
 using namespace KDAV;
 
-namespace KDAV
+DavPrincipalSearchJob::DavPrincipalSearchJob(const DavUrl &url, DavPrincipalSearchJob::FilterType type,
+        const QString &filter, QObject *parent)
+    : DavJobBase(parent), mUrl(url), mType(type), mFilter(filter), mPrincipalPropertySearchSubJobCount(0),
+      mPrincipalPropertySearchSubJobSuccessful(false)
 {
-class DavPrincipalSearchJobPrivate : public DavJobBasePrivate
-{
-public:
-    void buildReportQuery(QDomDocument &query) const;
-    void principalCollectionSetSearchFinished(KJob *job);
-    void principalPropertySearchFinished(KJob *job);
-
-    DavUrl mUrl;
-    DavPrincipalSearchJob::FilterType mType;
-    QString mFilter;
-    int mPrincipalPropertySearchSubJobCount = 0;
-    bool mPrincipalPropertySearchSubJobSuccessful = false;
-    struct PropertyInfo {
-        QString propNS;
-        QString propName;
-    };
-    std::vector<PropertyInfo> mFetchProperties;
-    QList<DavPrincipalSearchJob::Result> mResults;
-};
-}
-
-DavPrincipalSearchJob::DavPrincipalSearchJob(const DavUrl &url, DavPrincipalSearchJob::FilterType type, const QString &filter, QObject *parent)
-    : DavJobBase(new DavPrincipalSearchJobPrivate, parent)
-{
-    Q_D(DavPrincipalSearchJob);
-    d->mUrl = url;
-    d->mType = type;
-    d->mFilter = filter;
 }
 
 void DavPrincipalSearchJob::fetchProperty(const QString &name, const QString &ns)
 {
-    Q_D(DavPrincipalSearchJob);
-    d->mFetchProperties.push_back({!ns.isEmpty() ? ns : QStringLiteral("DAV:"), name});
+    QString propNamespace = ns;
+    if (propNamespace.isEmpty()) {
+        propNamespace = QStringLiteral("DAV:");
+    }
+
+    mFetchProperties << QPair<QString, QString>(propNamespace, name);
 }
 
 DavUrl DavPrincipalSearchJob::davUrl() const
 {
-    Q_D(const DavPrincipalSearchJob);
-    return d->mUrl;
+    return mUrl;
 }
 
 void DavPrincipalSearchJob::start()
 {
-    Q_D(DavPrincipalSearchJob);
     /*
      * The first step is to try to locate the URL that contains the principals.
      * This is done with a PROPFIND request and a XML like this:
@@ -86,19 +74,19 @@ void DavPrincipalSearchJob::start()
     QDomElement principalCollectionSet = query.createElementNS(QStringLiteral("DAV:"), QStringLiteral("principal-collection-set"));
     prop.appendChild(principalCollectionSet);
 
-    KIO::DavJob *job = DavManager::self()->createPropFindJob(d->mUrl.url(), query.toString());
+    KIO::DavJob *job = DavManager::self()->createPropFindJob(mUrl.url(), query);
     job->addMetaData(QStringLiteral("PropagateHttpHeader"), QStringLiteral("true"));
-    connect(job, &KIO::DavJob::result, this, [d](KJob *job) {
-        d->principalCollectionSetSearchFinished(job);
-    });
+    connect(job, &KIO::DavJob::result, this, &DavPrincipalSearchJob::principalCollectionSetSearchFinished);
     job->start();
 }
 
-void DavPrincipalSearchJobPrivate::principalCollectionSetSearchFinished(KJob *job)
+void DavPrincipalSearchJob::principalCollectionSetSearchFinished(KJob *job)
 {
     KIO::DavJob *davJob = qobject_cast<KIO::DavJob *>(job);
-    const QString responseCodeStr = davJob->queryMetaData(QStringLiteral("responsecode"));
-    const int responseCode = responseCodeStr.isEmpty() ? 0 : responseCodeStr.toInt();
+    const int responseCode = davJob->queryMetaData(QStringLiteral("responsecode")).isEmpty() ?
+                             0 :
+                             davJob->queryMetaData(QStringLiteral("responsecode")).toInt();
+
     // KIO::DavJob does not set error() even if the HTTP status code is a 4xx or a 5xx
     if (davJob->error() || (responseCode >= 400 && responseCode < 600)) {
         setLatestResponseCode(responseCode);
@@ -138,8 +126,7 @@ void DavPrincipalSearchJobPrivate::principalCollectionSetSearchFinished(KJob *jo
      * </D:multistatus>
      */
 
-    QDomDocument document;
-    document.setContent(davJob->responseData(), true);
+    QDomDocument document = davJob->response();
     QDomElement documentElement = document.documentElement();
 
     QDomElement responseElement = Utils::firstChildElementNS(documentElement, QStringLiteral("DAV:"), QStringLiteral("response"));
@@ -155,7 +142,7 @@ void DavPrincipalSearchJobPrivate::principalCollectionSetSearchFinished(KJob *jo
         for (int i = 0; i < propstats.length(); ++i) {
             const QDomElement propstatCandidate = propstats.item(i).toElement();
             const QDomElement statusElement = Utils::firstChildElementNS(propstatCandidate, QStringLiteral("DAV:"), QStringLiteral("status"));
-            if (statusElement.text().contains(QLatin1String("200"))) {
+            if (statusElement.text().contains(QStringLiteral("200"))) {
                 propstatElement = propstatCandidate;
             }
         }
@@ -197,17 +184,15 @@ void DavPrincipalSearchJobPrivate::principalCollectionSetSearchFinished(KJob *jo
 
         QDomDocument principalPropertySearchQuery;
         buildReportQuery(principalPropertySearchQuery);
-        KIO::DavJob *reportJob = DavManager::self()->createReportJob(url, principalPropertySearchQuery.toString());
+        KIO::DavJob *reportJob = DavManager::self()->createReportJob(url, principalPropertySearchQuery);
         reportJob->addMetaData(QStringLiteral("PropagateHttpHeader"), QStringLiteral("true"));
-        QObject::connect(reportJob, &KIO::DavJob::result, q_ptr, [this](KJob *job) {
-            principalPropertySearchFinished(job);
-        });
+        connect(reportJob, &KIO::DavJob::result, this, &DavPrincipalSearchJob::principalPropertySearchFinished);
         ++mPrincipalPropertySearchSubJobCount;
         reportJob->start();
     }
 }
 
-void DavPrincipalSearchJobPrivate::principalPropertySearchFinished(KJob *job)
+void DavPrincipalSearchJob::principalPropertySearchFinished(KJob *job)
 {
     --mPrincipalPropertySearchSubJobCount;
 
@@ -249,7 +234,7 @@ void DavPrincipalSearchJobPrivate::principalPropertySearchFinished(KJob *job)
     }
 
     if (!mPrincipalPropertySearchSubJobSuccessful) {
-        setError(0); // nope, everything went fine
+        setError(0);   // nope, everything went fine
         mPrincipalPropertySearchSubJobSuccessful = true;
     }
 
@@ -266,10 +251,9 @@ void DavPrincipalSearchJobPrivate::principalPropertySearchFinished(KJob *job)
      *       <D:status>HTTP/1.1 200 OK</D:status>
      *     </D:propstat>
      * </D:multistatus>
-     */
+    */
 
-    QDomDocument document;
-    document.setContent(davJob->responseData(), true);
+    const QDomDocument document = davJob->response();
     const QDomElement documentElement = document.documentElement();
 
     QDomElement responseElement = Utils::firstChildElementNS(documentElement, QStringLiteral("DAV:"), QStringLiteral("response"));
@@ -288,7 +272,7 @@ void DavPrincipalSearchJobPrivate::principalPropertySearchFinished(KJob *job)
         for (int i = 0; i < propStatsEnd; ++i) {
             const QDomElement propstatCandidate = propstats.item(i).toElement();
             const QDomElement statusElement = Utils::firstChildElementNS(propstatCandidate, QStringLiteral("DAV:"), QStringLiteral("status"));
-            if (statusElement.text().contains(QLatin1String("200"))) {
+            if (statusElement.text().contains(QStringLiteral("200"))) {
                 propstatElement = propstatCandidate;
             }
         }
@@ -310,12 +294,16 @@ void DavPrincipalSearchJobPrivate::principalPropertySearchFinished(KJob *job)
     }
 
     // All requested properties are now under propElement, so let's find them
-    for (const auto &[propNS, propName] : mFetchProperties) {
-        const QDomNodeList fetchNodes = propElement.elementsByTagNameNS(propNS, propName);
-        mResults.reserve(mResults.size() + fetchNodes.size());
+    typedef QPair<QString, QString> PropertyPair;
+    foreach (const PropertyPair &fetchProperty, mFetchProperties) {
+        QDomNodeList fetchNodes = propElement.elementsByTagNameNS(fetchProperty.first, fetchProperty.second);
         for (int i = 0; i < fetchNodes.size(); ++i) {
-            const QDomElement fetchElement = fetchNodes.at(i).toElement();
-            mResults.push_back({propNS, propName, fetchElement.text()});
+            QDomElement fetchElement = fetchNodes.at(i).toElement();
+            Result result;
+            result.propertyNamespace = fetchProperty.first;
+            result.property = fetchProperty.second;
+            result.value = fetchElement.text();
+            mResults << result;
         }
     }
 
@@ -324,13 +312,12 @@ void DavPrincipalSearchJobPrivate::principalPropertySearchFinished(KJob *job)
     }
 }
 
-QList<DavPrincipalSearchJob::Result> DavPrincipalSearchJob::results() const
+QList< DavPrincipalSearchJob::Result > DavPrincipalSearchJob::results() const
 {
-    Q_D(const DavPrincipalSearchJob);
-    return d->mResults;
+    return mResults;
 }
 
-void DavPrincipalSearchJobPrivate::buildReportQuery(QDomDocument &query) const
+void DavPrincipalSearchJob::buildReportQuery(QDomDocument &query)
 {
     /*
      * Build a document like the following, where XXX will
@@ -359,15 +346,14 @@ void DavPrincipalSearchJobPrivate::buildReportQuery(QDomDocument &query) const
     QDomElement prop = query.createElementNS(QStringLiteral("DAV:"), QStringLiteral("prop"));
     propertySearch.appendChild(prop);
 
-    if (mType == DavPrincipalSearchJob::DisplayName) {
+    if (mType == DisplayName) {
         QDomElement displayName = query.createElementNS(QStringLiteral("DAV:"), QStringLiteral("displayname"));
         prop.appendChild(displayName);
-    } else if (mType == DavPrincipalSearchJob::EmailAddress) {
-        QDomElement calendarUserAddressSet =
-            query.createElementNS(QStringLiteral("urn:ietf:params:xml:ns:caldav"), QStringLiteral("calendar-user-address-set"));
+    } else if (mType == EmailAddress) {
+        QDomElement calendarUserAddressSet = query.createElementNS(QStringLiteral("urn:ietf:params:xml:ns:caldav"), QStringLiteral("calendar-user-address-set"));
         prop.appendChild(calendarUserAddressSet);
-        // QDomElement hrefElement = query.createElementNS( "DAV:", "href" );
-        // prop.appendChild( hrefElement );
+        //QDomElement hrefElement = query.createElementNS( "DAV:", "href" );
+        //prop.appendChild( hrefElement );
     }
 
     QDomElement match = query.createElementNS(QStringLiteral("DAV:"), QStringLiteral("match"));
@@ -379,10 +365,9 @@ void DavPrincipalSearchJobPrivate::buildReportQuery(QDomDocument &query) const
     prop = query.createElementNS(QStringLiteral("DAV:"), QStringLiteral("prop"));
     principalPropertySearch.appendChild(prop);
 
-    for (const auto &[propNS, propName] : mFetchProperties) {
-        QDomElement elem = query.createElementNS(propNS, propName);
+    typedef QPair<QString, QString> PropertyPair;
+    foreach (const PropertyPair &fetchProperty, mFetchProperties) {
+        QDomElement elem = query.createElementNS(fetchProperty.first, fetchProperty.second);
         prop.appendChild(elem);
     }
 }
-
-#include "moc_davprincipalsearchjob.cpp"
