@@ -1,22 +1,36 @@
 /*
-    SPDX-FileCopyrightText: 2009 Grégory Oestreicher <greg@kamago.net>
+    Copyright (c) 2009 Grégory Oestreicher <greg@kamago.net>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
-#include "caldavprotocol_p.h"
-#include "common/utils_p.h"
+#include "caldavprotocol.h"
+#include "common/utils.h"
 
-#include <QDomDocument>
-#include <QStringList>
-#include <QUrl>
+#include <QtCore/QDateTime>
+#include <QtCore/QStringList>
+#include <QtCore/QUrl>
+#include <QtCore/QVariant>
+#include <QtXml/QDomDocument>
 
 using namespace KDAV;
 
 class CaldavCollectionQueryBuilder : public XMLQueryBuilder
 {
 public:
-    QDomDocument buildQuery() const override
+    QDomDocument buildQuery() const Q_DECL_OVERRIDE
     {
         QDomDocument document;
 
@@ -36,7 +50,7 @@ public:
         return document;
     }
 
-    QString mimeType() const override
+    QString mimeType() const Q_DECL_OVERRIDE
     {
         return QString();
     }
@@ -45,7 +59,7 @@ public:
 class CaldavListEventQueryBuilder : public XMLQueryBuilder
 {
 public:
-    QDomDocument buildQuery() const override
+    QDomDocument buildQuery() const Q_DECL_OVERRIDE
     {
         QString startTime = parameter(QStringLiteral("start")).toString();
         QString endTime = parameter(QStringLiteral("end")).toString();
@@ -101,7 +115,7 @@ public:
         return document;
     }
 
-    QString mimeType() const override
+    QString mimeType() const Q_DECL_OVERRIDE
     {
         return QStringLiteral("application/x-vnd.akonadi.calendar.event");
     }
@@ -110,7 +124,7 @@ public:
 class CaldavListTodoQueryBuilder : public XMLQueryBuilder
 {
 public:
-    QDomDocument buildQuery() const override
+    QDomDocument buildQuery() const Q_DECL_OVERRIDE
     {
         QString startTime = parameter(QStringLiteral("start")).toString();
         QString endTime = parameter(QStringLiteral("end")).toString();
@@ -166,7 +180,7 @@ public:
         return document;
     }
 
-    QString mimeType() const override
+    QString mimeType() const Q_DECL_OVERRIDE
     {
         return QStringLiteral("application/x-vnd.akonadi.calendar.todo");
     }
@@ -175,7 +189,7 @@ public:
 class CaldavListJournalQueryBuilder : public XMLQueryBuilder
 {
 public:
-    QDomDocument buildQuery() const override
+    QDomDocument buildQuery() const Q_DECL_OVERRIDE
     {
         QString startTime = parameter(QStringLiteral("start")).toString();
         QString endTime = parameter(QStringLiteral("end")).toString();
@@ -231,7 +245,7 @@ public:
         return document;
     }
 
-    QString mimeType() const override
+    QString mimeType() const Q_DECL_OVERRIDE
     {
         return QStringLiteral("application/x-vnd.akonadi.calendar.journal");
     }
@@ -240,7 +254,7 @@ public:
 class CaldavMultigetQueryBuilder : public XMLQueryBuilder
 {
 public:
-    QDomDocument buildQuery() const override
+    QDomDocument buildQuery() const Q_DECL_OVERRIDE
     {
         QDomDocument document;
         const QStringList urls = parameter(QStringLiteral("urls")).toStringList();
@@ -260,7 +274,7 @@ public:
         for (const QString &url : urls) {
             QDomElement hrefElement = document.createElementNS(QStringLiteral("DAV:"), QStringLiteral("href"));
             const QUrl pathUrl = QUrl::fromUserInput(url);
-            const QDomText textNode = document.createTextNode(pathUrl.path());
+            const QDomText textNode = document.createTextNode(pathUrl.toString());
             hrefElement.appendChild(textNode);
 
             multigetElement.appendChild(hrefElement);
@@ -269,7 +283,7 @@ public:
         return document;
     }
 
-    QString mimeType() const override
+    QString mimeType() const Q_DECL_OVERRIDE
     {
         return QString();
     }
@@ -309,14 +323,17 @@ XMLQueryBuilder::Ptr CaldavProtocol::collectionsQuery() const
     return XMLQueryBuilder::Ptr(new CaldavCollectionQueryBuilder());
 }
 
-bool CaldavProtocol::containsCollection(const QDomElement &propElem) const
+QString CaldavProtocol::collectionsXQuery() const
 {
-    return !propElem.elementsByTagNameNS(QStringLiteral("urn:ietf:params:xml:ns:caldav"), QStringLiteral("calendar")).isEmpty();
+    //const QString query( "//*[local-name()='calendar' and namespace-uri()='urn:ietf:params:xml:ns:caldav']/ancestor::*[local-name()='prop' and namespace-uri()='DAV:']/*[local-name()='supported-calendar-component-set' and namespace-uri()='urn:ietf:params:xml:ns:caldav']/*[local-name()='comp' and namespace-uri()='urn:ietf:params:xml:ns:caldav' and (@name='VTODO' or @name='VEVENT')]/ancestor::*[local-name()='response' and namespace-uri()='DAV:']" );
+    const QString query(QStringLiteral("//*[local-name()='calendar' and namespace-uri()='urn:ietf:params:xml:ns:caldav']/ancestor::*[local-name()='prop' and namespace-uri()='DAV:']/ancestor::*[local-name()='response' and namespace-uri()='DAV:']"));
+
+    return query;
 }
 
-QList<XMLQueryBuilder::Ptr> CaldavProtocol::itemsQueries() const
+QVector<XMLQueryBuilder::Ptr> CaldavProtocol::itemsQueries() const
 {
-    QList<XMLQueryBuilder::Ptr> ret;
+    QVector<XMLQueryBuilder::Ptr> ret;
     ret << XMLQueryBuilder::Ptr(new CaldavListEventQueryBuilder());
     ret << XMLQueryBuilder::Ptr(new CaldavListTodoQueryBuilder());
     ret << XMLQueryBuilder::Ptr(new CaldavListJournalQueryBuilder());
@@ -365,9 +382,7 @@ DavCollection::ContentTypes CaldavProtocol::collectionContentTypes(const QDomEle
      */
 
     const QDomElement propElement = Utils::firstChildElementNS(propstatElement, QStringLiteral("DAV:"), QStringLiteral("prop"));
-    const QDomElement supportedcomponentElement = Utils::firstChildElementNS(propElement, //
-                                                                             QStringLiteral("urn:ietf:params:xml:ns:caldav"),
-                                                                             QStringLiteral("supported-calendar-component-set"));
+    const QDomElement supportedcomponentElement = Utils::firstChildElementNS(propElement, QStringLiteral("urn:ietf:params:xml:ns:caldav"), QStringLiteral("supported-calendar-component-set"));
 
     DavCollection::ContentTypes contentTypes;
     QDomElement compElement = Utils::firstChildElementNS(supportedcomponentElement, QStringLiteral("urn:ietf:params:xml:ns:caldav"), QStringLiteral("comp"));
